@@ -24,6 +24,7 @@ use crate::{LocalMessage, Result};
 /// ```
 ///
 #[async_trait]
+#[allow(clippy::wrong_self_convention)]
 pub trait AccessControl: Send + Sync + 'static {
     /// Return true if the message is allowed to pass, and false if not.
     async fn is_authorized(&self, local_msg: &LocalMessage) -> Result<bool>;
@@ -52,8 +53,10 @@ impl AccessControl for DenyAll {
 #[cfg(feature = "alloc")]
 #[cfg(test)]
 mod tests {
-    use crate::Result;
-    use crate::{route, LocalMessage, TransportMessage};
+    use crate::{
+        errcode::{Kind, Origin},
+        route, LocalMessage, Result, TransportMessage,
+    };
     use futures_util::future::{Future, FutureExt};
 
     use super::{AccessControl, AllowAll, DenyAll};
@@ -126,7 +129,7 @@ mod tests {
         );
         match result {
             Poll::Ready(value) => value,
-            Poll::Pending => Err(crate::Error::new(1000, "SOME_ERROR_DOMAIN")),
+            Poll::Pending => Err(crate::Error::new_without_cause(Origin::Core, Kind::Unknown)),
         }
     }
 }
