@@ -25,6 +25,10 @@ extern crate core;
 #[macro_use]
 extern crate alloc;
 
+// Allow use of logging macros directly.
+#[macro_use]
+extern crate tracing;
+
 pub use async_trait::async_trait;
 
 #[allow(unused_imports)]
@@ -50,7 +54,6 @@ mod error;
 mod message;
 mod processor;
 mod routing;
-pub mod traits;
 mod uint;
 pub mod vault;
 mod worker;
@@ -60,13 +63,42 @@ pub use error::*;
 pub use message::*;
 pub use processor::*;
 pub use routing::*;
-pub use traits::*;
 pub use uint::*;
 pub use worker::*;
 
 #[cfg(all(not(feature = "std"), feature = "alloc"))]
 #[doc(hidden)]
 pub use compat::println;
+
 #[cfg(feature = "std")]
 #[doc(hidden)]
 pub use std::println;
+
+use crate::compat::boxed::Box;
+
+/// Clone trait for async structs.
+#[async_trait]
+pub trait AsyncTryClone: Sized {
+    /// Try cloning a object and return an `Err` in case of failure.
+    async fn async_try_clone(&self) -> Result<Self>;
+}
+
+#[async_trait]
+impl<D> AsyncTryClone for D
+where
+    D: Clone + Sync,
+{
+    async fn async_try_clone(&self) -> Result<Self> {
+        Ok(self.clone())
+    }
+}
+
+/// Produces Ok(false) to avoid an ambiguous reading from using the unadorned value in auth code.
+pub fn deny() -> Result<bool> {
+    Ok(false)
+}
+
+/// Produces Ok(true) to avoid an ambiguous reading from using the unadorned value in auth code.
+pub fn allow() -> Result<bool> {
+    Ok(true)
+}
