@@ -3,8 +3,5 @@
 mod transport_message;
 pub use transport_message::*;
 
-mod router_message;
-pub use router_message::*;
-
 mod local_message;
 pub use local_message::*;
