@@ -1,3 +1,4 @@
+use crate::vault::Secret;
 use cfg_if::cfg_if;
 use serde::{Deserialize, Serialize};
 use zeroize::Zeroize;
@@ -51,7 +52,7 @@ cfg_if! {
 }
 
 /// Binary representation of a Secret.
-#[derive(Serialize, Deserialize, Clone, Debug, Eq, PartialEq, Zeroize)]
+#[derive(Serialize, Deserialize, Clone, Zeroize)]
 #[zeroize(drop)]
 pub struct SecretKey(SecretKeyVec);
 
@@ -62,6 +63,19 @@ impl SecretKey {
     }
 }
 
+impl core::fmt::Debug for SecretKey {
+    fn fmt(&self, f: &mut core::fmt::Formatter) -> core::fmt::Result {
+        f.pad("<secret key omitted>")
+    }
+}
+
+impl Eq for SecretKey {}
+impl PartialEq for SecretKey {
+    fn eq(&self, o: &Self) -> bool {
+        subtle::ConstantTimeEq::ct_eq(&self.0[..], &o.0[..]).into()
+    }
+}
+
 impl AsRef<[u8]> for SecretKey {
     fn as_ref(&self) -> &[u8] {
         &self.0
@@ -69,13 +83,21 @@ impl AsRef<[u8]> for SecretKey {
 }
 
 /// A public key.
-#[derive(Serialize, Deserialize, Clone, Debug, Eq, PartialEq, Zeroize)]
+#[derive(Serialize, Deserialize, Clone, Debug, Zeroize)]
 #[zeroize(drop)]
 pub struct PublicKey {
     data: PublicKeyVec,
     stype: SecretType,
 }
 
+impl Eq for PublicKey {}
+impl PartialEq for PublicKey {
+    fn eq(&self, o: &Self) -> bool {
+        let choice = subtle::ConstantTimeEq::ct_eq(&self.data[..], &o.data[..]);
+        choice.into() && self.stype == o.stype
+    }
+}
+
 impl PublicKey {
     /// Public Key data.
     pub fn data(&self) -> &[u8] {
@@ -101,7 +123,7 @@ impl AsRef<[u8]> for PublicKey {
 }
 
 /// Binary representation of Signature.
-#[derive(Serialize, Deserialize, Clone, Debug, Eq, PartialEq, Zeroize)]
+#[derive(Serialize, Deserialize, Clone, Debug, Zeroize)]
 #[zeroize(drop)]
 pub struct Signature(SignatureVec);
 
@@ -118,6 +140,13 @@ impl AsRef<[u8]> for Signature {
     }
 }
 
+impl Eq for Signature {}
+impl PartialEq for Signature {
+    fn eq(&self, o: &Self) -> bool {
+        subtle::ConstantTimeEq::ct_eq(&self.0[..], &o.0[..]).into()
+    }
+}
+
 /// All possible [`SecretType`]s
 #[derive(Serialize, Deserialize, Copy, Clone, Debug, Eq, PartialEq, Zeroize)]
 pub enum SecretType {
@@ -176,3 +205,29 @@ impl SecretAttributes {
         }
     }
 }
+
+/// A public key
+#[derive(Clone, Debug, Zeroize)]
+#[zeroize(drop)]
+pub struct KeyPair {
+    secret: Secret,
+    public: PublicKey,
+}
+
+impl KeyPair {
+    /// Secret key
+    pub fn secret(&self) -> &Secret {
+        &self.secret
+    }
+    /// Public Key
+    pub fn public(&self) -> &PublicKey {
+        &self.public
+    }
+}
+
+impl KeyPair {
+    /// Create a new key pair
+    pub fn new(secret: Secret, public: PublicKey) -> Self {
+        Self { secret, public }
+    }
+}
